/* qdbusdatalist.h list of DBUS data transport type
 *
 * Copyright (C) 2007 Kevin Krammer <kevin.krammer@gmx.at>
 *
 * Licensed under the Academic Free License version 2.1
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 *
 */

#ifndef QDBUSDATALIST_H
#define QDBUSDATALIST_H

#include "dbus/qdbusdata.h"

template <typename T> class QValueList;
class QDBusVariant;
class QString;
class QStringList;

class QDBUS_EXPORT QDBusDataList
{
public:
    QDBusDataList();

    QDBusDataList(QDBusData::Type simpleItemType);

    QDBusDataList(const QDBusData& containerItemType);

    QDBusDataList(const QDBusDataList& other);

    QDBusDataList(const QValueList<QDBusData>& other);

    QDBusDataList(const QValueList<bool>& other);

    QDBusDataList(const QValueList<Q_UINT8>& other);

    QDBusDataList(const QValueList<Q_INT16>& other);

    QDBusDataList(const QValueList<Q_UINT16>& other);

    QDBusDataList(const QValueList<Q_INT32>& other);

    QDBusDataList(const QValueList<Q_UINT32>& other);

    QDBusDataList(const QValueList<Q_INT64>& other);

    QDBusDataList(const QValueList<Q_UINT64>& other);

    QDBusDataList(const QValueList<double>& other);

    QDBusDataList(const QValueList<QDBusVariant>& other);

    QDBusDataList(const QStringList& other);

    ~QDBusDataList();

    QDBusDataList& operator=(const QDBusDataList& other);

    QDBusDataList& operator=(const QValueList<QDBusData>& other);

    QDBusDataList& operator=(const QStringList& other);

    QDBusData::Type type() const;

    inline bool isValid() const { return type() != QDBusData::Invalid; }

    bool isEmpty() const;

    uint count() const;

    bool hasContainerItemType() const;

    QDBusData containerItemType() const;

    bool operator==(const QDBusDataList& other) const;

    bool operator!=(const QDBusDataList& other) const;

    QDBusDataList& operator<<(const QDBusData& data);

    QValueList<QDBusData> toQValueList() const;

    QStringList toQStringList(bool* ok = 0) const;

    QValueList<bool> toBoolList(bool* ok = 0) const;

    QValueList<Q_UINT8> toByteList(bool* ok = 0) const;

    QValueList<Q_INT16> toInt16List(bool* ok = 0) const;

    QValueList<Q_UINT16> toUInt16List(bool* ok = 0) const;

    QValueList<Q_INT32> toInt32List(bool* ok = 0) const;

    QValueList<Q_UINT32> toUInt32List(bool* ok = 0) const;

    QValueList<Q_INT64> toInt64List(bool* ok = 0) const;

    QValueList<Q_UINT64> toUInt64List(bool* ok = 0) const;

    QValueList<double> toDoubleList(bool* ok = 0) const;

    QValueList<QString> toStringList(bool* ok = 0) const;

    QValueList<QDBusVariant> toVariantList(bool* ok = 0) const;

private:
    class Private;
    Private* d;
};

#endif
